@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # build.py --- Convenience script for building and running Jami
 
-# Copyright (C) 2016-2025 Savoir-faire Linux Inc.
+# Copyright (C) 2016-2026 Savoir-faire Linux Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -216,7 +216,7 @@ UNINSTALL_DAEMON_SCRIPT = [
 ASSUME_YES_FLAG = ' -y'
 ASSUME_YES_FLAG_PACMAN = ' --noconfirm'
 
-GUIX_MANIFEST = 'extras/packaging/gnu-linux/guix/manifest.scm'
+GUIX_MANIFEST = 'extras/packaging/gnu-linux/guix/client+daemon-manifest.scm'
 
 
 def run_powershell_cmd(cmd):
@@ -300,7 +300,7 @@ def run_dependencies(args):
         sys.exit(1)
     elif args.distribution == 'guix':
         print(f"Building the profile defined in '{GUIX_MANIFEST}'…")
-        execute_script([f'guix shell --manifest={GUIX_MANIFEST} -- true'])
+        execute_script([f'guix build --manifest={GUIX_MANIFEST}'])
 
     else:
         print("Not yet implemented for current distribution (%s). Please continue with the --install instruction. Note: You may need to install some dependencies manually." %
@@ -458,10 +458,8 @@ def run_install(args):
             share_tarballs_args = ['--preserve=TARBALLS',
                                    f'--share={os.environ["TARBALLS"]}']
         command = ['guix', 'shell', f'--manifest={GUIX_MANIFEST}',
-                   '--symlink=/usr/bin/env=bin/env',
-                   '--symlink=/etc/ssl/certs=etc/ssl/certs',
-                   '--container', '--network'] + share_tarballs_args \
-            + ['--'] + command
+                   '--container', '--network', '--emulate-fhs'] \
+                   + share_tarballs_args + ['--'] + command
 
     print(f'info: Building/installing using the command: {" ".join(command)}')
     return subprocess.run(command, env=environ, check=True)
@@ -511,10 +509,11 @@ def clean_contribs(contribs):
     contrib_dir = 'daemon/contrib'
     sub_dirs = os.listdir(contrib_dir)
 
-    # Let's find the abi triplet:
-    # The abi_triplet is 3 parts: <arch>-<vendor>-<sys> and should be the only directory
-    # named like that in the contrib directory. We can use a regex to find it.
-    triplet_pattern = re.compile(r'^[a-zA-Z0-9_]+-[a-zA-Z0-9_]+-[a-zA-Z0-9_]+$')
+    # Let's find the GNU triplet/quadruplet which is 3 or 4 parts:
+    # <arch>-<vendor>-<sys>[-<abi>] and should be the only directory
+    # named like that in the contrib directory. We can use a regex to
+    # find it.
+    triplet_pattern = re.compile(r'^[a-zA-Z0-9_]+(-[a-zA-Z0-9_]+){2,3}$')
     def is_triplet(s):
         return bool(triplet_pattern.match(s))
     abi_triplet = ''
@@ -529,27 +528,27 @@ def clean_contribs(contribs):
         sys.exit(1)
 
     # Let's find the native build source directory (native-*)
-    native_dir = ''
+    build_dir = ''
     for sub_dir in sub_dirs:
-        if sub_dir.startswith('native'):
-            native_dir = os.path.join(contrib_dir, sub_dir)
+        if sub_dir.startswith('native') or sub_dir.startswith('build'):
+            build_dir = os.path.join(contrib_dir, sub_dir)
             break
 
     # If we didn't find the native build source directory, we need to stop.
-    if native_dir == '':
+    if build_dir == '':
         print('Could not find the native build source directory. Exiting.')
         sys.exit(1)
 
     # If contribs is 'all', construct the list of all contribs from the contrib native directory
     # list of directories only
     if contribs == ['all']:
-        contribs = [d for d in os.listdir(native_dir) if os.path.isdir(os.path.join(native_dir, d))]
+        contribs = [d for d in os.listdir(build_dir) if os.path.isdir(os.path.join(build_dir, d))]
 
     # Clean each contrib
     for contrib in contribs:
-        print(f'Cleaning contrib: {contrib} for {abi_triplet} in {native_dir}')
-        build_dir = os.path.join(native_dir, contrib, '*')
-        build_stamp = os.path.join(native_dir, f'.{contrib}*')
+        print(f'Cleaning contrib: {contrib} for {abi_triplet} in {build_dir}')
+        build_dir = os.path.join(build_dir, contrib, '*')
+        build_stamp = os.path.join(build_dir, f'.{contrib}*')
         tarball = os.path.join(contrib_dir, 'tarballs', f'{contrib}*.tar.*')
         bins = os.path.join(contrib_dir, abi_triplet, 'bin', contrib)
         libs = os.path.join(contrib_dir, abi_triplet, 'lib', f'lib{contrib}*')
@@ -771,7 +770,7 @@ def parse_args():
     ap.add_argument('--enable-crash-reports',
                     action='store_true', default=False,
                     help='Enable crash reporting')
-    ap.add_argument('--ignore_system_libs', dest='ignore_system_libs',
+    ap.add_argument('--ignore-system-libs', dest='ignore_system_libs',
                     default=False, action='store_true',
                     help='Build contrib packages regardless of system detection')
 
@@ -845,7 +844,12 @@ def main():
             # Relaunch this script, this time in a pure Guix environment.
             guix_args = ['shell', '--pure',
                          # to allow pulseaudio to connect to an existing server
-                         "-E", "XAUTHORITY", "-E", "XDG_RUNTIME_DIR",
+                         "-E", "GTK_DATA_PREFIX", # for theming on Guix System
+                         "-E", "QT_QPA_PLATFORM",
+                         "-E", "XAUTHORITY",
+                         "-E", "XCURSOR_PATH",
+                         "-E", "^XDG",
+                         "-E", "WAYLAND_DISPLAY",
                          f'--manifest={GUIX_MANIFEST}', '--']
             args = sys.argv + ['--distribution=guix']
             print('Running in a guix shell spawned with: guix {}'
