@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 #include "string_utils.h"
 #include "logger.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include <iostream>
 #include <unistd.h>
@@ -119,7 +119,7 @@ MediaDemuxer::openInput(const DeviceParams& params)
 
         if (params.framerate) {
 #ifdef _WIN32
-            // On windows, framerate settings don't reduce to avrational values
+            // On Windows, framerate settings don't reduce to avrational values
             // that correspond to valid video device formats.
             // e.g. A the rational<double>(10000000, 333333) or 30.000030000
             //      will be reduced by av_reduce to 999991/33333 or 30.00003000003
@@ -190,7 +190,7 @@ MediaDemuxer::openInput(const DeviceParams& params)
     } else if (inputCtx_->nb_streams > 0 && inputCtx_->streams[0]->codecpar) {
         baseWidth_ = inputCtx_->streams[0]->codecpar->width;
         baseHeight_ = inputCtx_->streams[0]->codecpar->height;
-        JAMI_LOG("Opened input Using format {:s} and resolution {:d}x{:d}", params.format, baseWidth_, baseHeight_);
+        JAMI_LOG("Opened input using format {:s} and resolution {:d}x{:d}", params.format, baseWidth_, baseHeight_);
     }
 
     return ret;
@@ -556,7 +556,7 @@ MediaDecoder::setupStream()
                 accel_.reset();
                 continue;
             } else {
-                // Succeed to open codec
+                // Codec opened successfully.
                 JAMI_WARN("Using hardware decoding for %s with %s",
                           avcodec_get_name(decoderCtx_->codec_id),
                           it.getName().c_str());
@@ -573,7 +573,7 @@ MediaDecoder::setupStream()
     decoderCtx_->thread_count = std::max(1u, std::min(8u, std::thread::hardware_concurrency() / 2));
     if (emulateRate_)
         JAMI_DBG() << "Using framerate emulation";
-    startTime_ = av_gettime(); // used to set pts after decoding, and for rate emulation
+    startTime_ = av_gettime(); // Used to set pts after decoding, and for rate emulation
 
 #ifdef ENABLE_HWACCEL
     if (!accel_) {
@@ -694,8 +694,19 @@ MediaDecoder::decode(AVPacket& packet)
         frameFinished = 1;
 
     if (frameFinished) {
-        if (inputDecoder_->type == AVMEDIA_TYPE_VIDEO)
+        if (inputDecoder_->type == AVMEDIA_TYPE_VIDEO) {
             frame->format = (AVPixelFormat) correctPixFmt(frame->format);
+        } else {
+            // It's possible (albeit rare) for avcodec_receive_frame to return a frame with
+            // unspecified channel order. This can cause issues later on in the resampler
+            // because swr_convert_frame expects the ch_layout of the input frame to match
+            // the in_ch_layout of the SwrContext, but swr_init sets in_ch_layout to a default
+            // value based on the number of channels if the channel order of the input frame
+            // is unspecified.
+            if (frame->ch_layout.order == AV_CHANNEL_ORDER_UNSPEC) {
+                av_channel_layout_default(&frame->ch_layout, frame->ch_layout.nb_channels);
+            }
+        }
         auto packetTimestamp = frame->pts; // in stream time base
         frame->pts = av_rescale_q_rnd(av_gettime() - startTime_,
                                       {1, AV_TIME_BASE},
