@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #include "logger.h"
 #include "../video_device.h"
 
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include <algorithm>
 #include <map>
@@ -43,7 +43,7 @@ struct android_fmt
 };
 
 static const std::array<android_fmt, 2> and_formats {
-    android_fmt {17, "NV21", AV_PIX_FMT_NV21},
+    android_fmt {17,        "NV21",   AV_PIX_FMT_NV21   },
     android_fmt {842094169, "YUV420", AV_PIX_FMT_YUV420P},
 };
 
