@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2021-2026 Savoir-faire Linux Inc.
  *
  *
  *  This program is free software: you can redistribute it and/or modify
@@ -18,12 +18,14 @@
 
 #include <libguile.h>
 
-void inner_main(void *, int argc, char **argv)
+void
+inner_main(void*, int argc, char** argv)
 {
     scm_shell(argc, argv);
 }
 
-int main(int argc, char *argv[])
+int
+main(int argc, char* argv[])
 {
     (void) scm_boot_guile(argc, argv, inner_main, NULL);
     __builtin_unreachable();
