@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,7 +45,8 @@ using namespace libjami::Account;
 namespace jami {
 namespace test {
 
-struct UserData {
+struct UserData
+{
     std::string conversationId;
     bool requestReceived {false};
     bool registered {false};
@@ -61,8 +62,7 @@ public:
     static std::string name() { return "Conversation"; }
     void setUp();
     void tearDown();
-    std::string createFakeConversation(std::shared_ptr<JamiAccount> account,
-                                       const std::string& fakeCert = "");
+    std::string createFakeConversation(std::shared_ptr<JamiAccount> account, const std::string& fakeCert = "");
 
     std::string aliceId;
     UserData aliceData;
@@ -99,8 +99,7 @@ void
 ConversationFetchSentTest::setUp()
 {
     // Init daemon
-    libjami::init(
-        libjami::InitFlag(libjami::LIBJAMI_FLAG_DEBUG | libjami::LIBJAMI_FLAG_CONSOLE_LOG));
+    libjami::init(libjami::InitFlag(libjami::LIBJAMI_FLAG_DEBUG | libjami::LIBJAMI_FLAG_CONSOLE_LOG));
     if (not Manager::instance().initialized)
         CPPUNIT_ASSERT(libjami::start("jami-sample.yml"));
 
@@ -123,58 +122,58 @@ void
 ConversationFetchSentTest::connectSignals()
 {
     std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> confHandlers;
-    confHandlers.insert(
-        libjami::exportable_callback<libjami::ConfigurationSignal::VolatileDetailsChanged>(
-            [&](const std::string& accountId, const std::map<std::string, std::string>&) {
-                if (accountId == aliceId) {
-                    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
-                    auto details = aliceAccount->getVolatileAccountDetails();
-                    auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
-                    if (daemonStatus == "REGISTERED") {
-                        aliceData.registered = true;
-                    } else if (daemonStatus == "UNREGISTERED") {
-                        aliceData.stopped = true;
-                    }
-                    auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
-                    aliceData.deviceAnnounced = deviceAnnounced == "true";
-                } else if (accountId == bobId) {
-                    auto bobAccount = Manager::instance().getAccount<JamiAccount>(bobId);
-                    auto details = bobAccount->getVolatileAccountDetails();
-                    auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
-                    if (daemonStatus == "REGISTERED") {
-                        bobData.registered = true;
-                    } else if (daemonStatus == "UNREGISTERED") {
-                        bobData.stopped = true;
-                    }
-                    auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
-                    bobData.deviceAnnounced = deviceAnnounced == "true";
-                } else if (accountId == bob2Id) {
-                    auto bob2Account = Manager::instance().getAccount<JamiAccount>(bob2Id);
-                    auto details = bob2Account->getVolatileAccountDetails();
-                    auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
-                    if (daemonStatus == "REGISTERED") {
-                        bob2Data.registered = true;
-                    } else if (daemonStatus == "UNREGISTERED") {
-                        bob2Data.stopped = true;
-                    }
-                    auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
-                    bob2Data.deviceAnnounced = deviceAnnounced == "true";
-                } else if (accountId == carlaId) {
-                    auto carlaAccount = Manager::instance().getAccount<JamiAccount>(carlaId);
-                    auto details = carlaAccount->getVolatileAccountDetails();
-                    auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
-                    if (daemonStatus == "REGISTERED") {
-                        carlaData.registered = true;
-                    } else if (daemonStatus == "UNREGISTERED") {
-                        carlaData.stopped = true;
-                    }
-                    auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
-                    carlaData.deviceAnnounced = deviceAnnounced == "true";
+    confHandlers.insert(libjami::exportable_callback<libjami::ConfigurationSignal::VolatileDetailsChanged>(
+        [&](const std::string& accountId, const std::map<std::string, std::string>&) {
+            if (accountId == aliceId) {
+                auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+                auto details = aliceAccount->getVolatileAccountDetails();
+                auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
+                if (daemonStatus == "REGISTERED") {
+                    aliceData.registered = true;
+                } else if (daemonStatus == "UNREGISTERED") {
+                    aliceData.stopped = true;
                 }
-                cv.notify_one();
-            }));
+                auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
+                aliceData.deviceAnnounced = deviceAnnounced == "true";
+            } else if (accountId == bobId) {
+                auto bobAccount = Manager::instance().getAccount<JamiAccount>(bobId);
+                auto details = bobAccount->getVolatileAccountDetails();
+                auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
+                if (daemonStatus == "REGISTERED") {
+                    bobData.registered = true;
+                } else if (daemonStatus == "UNREGISTERED") {
+                    bobData.stopped = true;
+                }
+                auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
+                bobData.deviceAnnounced = deviceAnnounced == "true";
+            } else if (accountId == bob2Id) {
+                auto bob2Account = Manager::instance().getAccount<JamiAccount>(bob2Id);
+                auto details = bob2Account->getVolatileAccountDetails();
+                auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
+                if (daemonStatus == "REGISTERED") {
+                    bob2Data.registered = true;
+                } else if (daemonStatus == "UNREGISTERED") {
+                    bob2Data.stopped = true;
+                }
+                auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
+                bob2Data.deviceAnnounced = deviceAnnounced == "true";
+            } else if (accountId == carlaId) {
+                auto carlaAccount = Manager::instance().getAccount<JamiAccount>(carlaId);
+                auto details = carlaAccount->getVolatileAccountDetails();
+                auto daemonStatus = details[libjami::Account::ConfProperties::Registration::STATUS];
+                if (daemonStatus == "REGISTERED") {
+                    carlaData.registered = true;
+                } else if (daemonStatus == "UNREGISTERED") {
+                    carlaData.stopped = true;
+                }
+                auto deviceAnnounced = details[libjami::Account::VolatileProperties::DEVICE_ANNOUNCED];
+                carlaData.deviceAnnounced = deviceAnnounced == "true";
+            }
+            cv.notify_one();
+        }));
     confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::SwarmLoaded>(
-        [&](uint32_t, const std::string& accountId,
+        [&](uint32_t,
+            const std::string& accountId,
             const std::string& /* conversationId */,
             std::vector<libjami::SwarmMessage> messages) {
             if (accountId == aliceId) {
@@ -201,26 +200,23 @@ ConversationFetchSentTest::connectSignals()
             }
             cv.notify_one();
         }));
-    confHandlers.insert(
-        libjami::exportable_callback<libjami::ConversationSignal::ConversationRequestReceived>(
-            [&](const std::string& accountId,
-                const std::string& /* conversationId */,
-                std::map<std::string, std::string> /*metadatas*/) {
-                if (accountId == aliceId) {
-                    aliceData.requestReceived = true;
-                } else if (accountId == bobId) {
-                    bobData.requestReceived = true;
-                } else if (accountId == bob2Id) {
-                    bob2Data.requestReceived = true;
-                } else if (accountId == carlaId) {
-                    carlaData.requestReceived = true;
-                }
-                cv.notify_one();
-            }));
-    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::SwarmMessageReceived>(
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::ConversationRequestReceived>(
         [&](const std::string& accountId,
             const std::string& /* conversationId */,
-            libjami::SwarmMessage message) {
+            std::map<std::string, std::string> /*metadatas*/) {
+            if (accountId == aliceId) {
+                aliceData.requestReceived = true;
+            } else if (accountId == bobId) {
+                bobData.requestReceived = true;
+            } else if (accountId == bob2Id) {
+                bob2Data.requestReceived = true;
+            } else if (accountId == carlaId) {
+                carlaData.requestReceived = true;
+            }
+            cv.notify_one();
+        }));
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::SwarmMessageReceived>(
+        [&](const std::string& accountId, const std::string& /* conversationId */, libjami::SwarmMessage message) {
             if (accountId == aliceId) {
                 aliceData.messages.emplace_back(message);
             } else if (accountId == bobId) {
@@ -232,30 +228,29 @@ ConversationFetchSentTest::connectSignals()
             }
             cv.notify_one();
         }));
-    confHandlers.insert(
-        libjami::exportable_callback<libjami::ConfigurationSignal::AccountMessageStatusChanged>(
-            [&](const std::string& accountId,
-                const std::string& /*conversationId*/,
-                const std::string& peer,
-                const std::string& msgId,
-                int status) {
-                auto placeMessage = [&](auto& data) {
-                    for (auto& dataMsg : data.messages) {
-                        if (dataMsg.id == msgId) {
-                            dataMsg.status[peer] = status;
-                            return;
-                        }
+    confHandlers.insert(libjami::exportable_callback<libjami::ConfigurationSignal::AccountMessageStatusChanged>(
+        [&](const std::string& accountId,
+            const std::string& /*conversationId*/,
+            const std::string& peer,
+            const std::string& msgId,
+            int status) {
+            auto placeMessage = [&](auto& data) {
+                for (auto& dataMsg : data.messages) {
+                    if (dataMsg.id == msgId) {
+                        dataMsg.status[peer] = status;
+                        return;
                     }
-                };
-                if (accountId == aliceId) {
-                    placeMessage(aliceData);
-                } else if (accountId == bobId) {
-                    placeMessage(bobData);
-                } else if (accountId == bob2Id) {
-                    placeMessage(bob2Data);
                 }
-                cv.notify_one();
-            }));
+            };
+            if (accountId == aliceId) {
+                placeMessage(aliceData);
+            } else if (accountId == bobId) {
+                placeMessage(bobData);
+            } else if (accountId == bob2Id) {
+                placeMessage(bob2Data);
+            }
+            cv.notify_one();
+        }));
     libjami::registerSignalHandlers(confHandlers);
 }
 
@@ -309,17 +304,19 @@ ConversationFetchSentTest::testSyncAfterDisconnection()
     aliceAccount->sendTrustRequest(bobUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return bobData.requestReceived; }));
     CPPUNIT_ASSERT(bobAccount->acceptTrustRequest(aliceUri));
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return !bobData.conversationId.empty() && !bob2Data.conversationId.empty(); }));
+    CPPUNIT_ASSERT(
+        cv.wait_for(lk, 30s, [&]() { return !bobData.conversationId.empty() && !bob2Data.conversationId.empty(); }));
 
     std::this_thread::sleep_for(5s); // Wait for all join messages to be received
 
     // bob send 4 messages
-    auto aliceMsgSize = aliceData.messages.size(), bob2MsgSize = bob2Data.messages.size(), bobMsgSize = bobData.messages.size();
+    auto aliceMsgSize = aliceData.messages.size(), bob2MsgSize = bob2Data.messages.size(),
+         bobMsgSize = bobData.messages.size();
     libjami::sendMessage(bobId, bobData.conversationId, "1"s, "");
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
-        return aliceData.messages.size() == aliceMsgSize + 1
-                && bobData.messages.size() == bobMsgSize + 1
-                && bob2Data.messages.size() == bob2MsgSize + 1; }));
+        return aliceData.messages.size() == aliceMsgSize + 1 && bobData.messages.size() == bobMsgSize + 1
+               && bob2Data.messages.size() == bob2MsgSize + 1;
+    }));
     auto msgId1 = aliceData.messages.rbegin()->id;
     auto getMsgStatus = [&](const auto& data, const auto& id, const auto& peer) {
         for (const auto& msg : data.messages) {
@@ -329,27 +326,41 @@ ConversationFetchSentTest::testSyncAfterDisconnection()
         }
         return libjami::Account::MessageStates::UNKNOWN;
     };
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "2"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 2
-                                                    && bobData.messages.size() == bobMsgSize + 2
-                                                    && bob2Data.messages.size() == bob2MsgSize + 2;}));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 2 && bobData.messages.size() == bobMsgSize + 2
+               && bob2Data.messages.size() == bob2MsgSize + 2;
+    }));
     auto msgId2 = aliceData.messages.rbegin()->id;
     // Because bob2Data.status is here only on update, but msgReceived can be good directly at first
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "3"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 3
-                                                    && bobData.messages.size() == bobMsgSize + 3
-                                                    && bob2Data.messages.size() == bob2MsgSize + 3; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 3 && bobData.messages.size() == bobMsgSize + 3
+               && bob2Data.messages.size() == bob2MsgSize + 3;
+    }));
     auto msgId3 = aliceData.messages.rbegin()->id;
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId3, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId3, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId3, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId3, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "4"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 4
-                                                    && bobData.messages.size() == bobMsgSize + 4
-                                                    && bob2Data.messages.size() == bob2MsgSize + 4; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 4 && bobData.messages.size() == bobMsgSize + 4
+               && bob2Data.messages.size() == bob2MsgSize + 4;
+    }));
     auto msgId4 = aliceData.messages.rbegin()->id;
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId4, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId4, aliceUri) == libjami::Account::MessageStates::SENT; }));
-
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId4, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId4, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
 
     // Bob is disabled. Bob2 will get the infos
     Manager::instance().sendRegister(bobId, false);
@@ -357,8 +368,10 @@ ConversationFetchSentTest::testSyncAfterDisconnection()
 
     // Second message is set to displayed by alice
     aliceAccount->setMessageDisplayed("swarm:" + aliceData.conversationId, msgId2, 3);
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
-                                                && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
+               && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED;
+    }));
     CPPUNIT_ASSERT(getMsgStatus(bobData, msgId1, aliceUri) != libjami::Account::MessageStates::DISPLAYED);
 
     // Alice is disabled so she will not sync
@@ -367,8 +380,10 @@ ConversationFetchSentTest::testSyncAfterDisconnection()
 
     // Bob is enabled again, should sync infos with bob2
     Manager::instance().sendRegister(bobId, true);
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
-                                                && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
+               && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED;
+    }));
 }
 
 void
@@ -403,17 +418,19 @@ ConversationFetchSentTest::testSyncFetch()
     aliceAccount->sendTrustRequest(bobUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return bobData.requestReceived; }));
     CPPUNIT_ASSERT(bobAccount->acceptTrustRequest(aliceUri));
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return !bobData.conversationId.empty() && !bob2Data.conversationId.empty(); }));
+    CPPUNIT_ASSERT(
+        cv.wait_for(lk, 30s, [&]() { return !bobData.conversationId.empty() && !bob2Data.conversationId.empty(); }));
 
     std::this_thread::sleep_for(5s); // Wait for all join messages to be received
 
     // bob send 4 messages
-    auto aliceMsgSize = aliceData.messages.size(), bob2MsgSize = bob2Data.messages.size(), bobMsgSize = bobData.messages.size();
+    auto aliceMsgSize = aliceData.messages.size(), bob2MsgSize = bob2Data.messages.size(),
+         bobMsgSize = bobData.messages.size();
     libjami::sendMessage(bobId, bobData.conversationId, "1"s, "");
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
-        return aliceData.messages.size() == aliceMsgSize + 1
-                && bobData.messages.size() == bobMsgSize + 1
-                && bob2Data.messages.size() == bob2MsgSize + 1; }));
+        return aliceData.messages.size() == aliceMsgSize + 1 && bobData.messages.size() == bobMsgSize + 1
+               && bob2Data.messages.size() == bob2MsgSize + 1;
+    }));
     auto msgId1 = aliceData.messages.rbegin()->id;
     auto getMsgStatus = [&](const auto& data, const auto& id, const auto& peer) {
         for (const auto& msg : data.messages) {
@@ -423,42 +440,61 @@ ConversationFetchSentTest::testSyncFetch()
         }
         return libjami::Account::MessageStates::UNKNOWN;
     };
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "2"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 2
-                                                    && bobData.messages.size() == bobMsgSize + 2
-                                                    && bob2Data.messages.size() == bob2MsgSize + 2;}));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 2 && bobData.messages.size() == bobMsgSize + 2
+               && bob2Data.messages.size() == bob2MsgSize + 2;
+    }));
     auto msgId2 = aliceData.messages.rbegin()->id;
     // Because bob2Data.status is here only on update, but msgReceived can be good directly at first
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "3"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 3
-                                                    && bobData.messages.size() == bobMsgSize + 3
-                                                    && bob2Data.messages.size() == bob2MsgSize + 3; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 3 && bobData.messages.size() == bobMsgSize + 3
+               && bob2Data.messages.size() == bob2MsgSize + 3;
+    }));
     auto msgId3 = aliceData.messages.rbegin()->id;
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId3, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId3, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId3, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId3, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "4"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 4
-                                                    && bobData.messages.size() == bobMsgSize + 4
-                                                    && bob2Data.messages.size() == bob2MsgSize + 4; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 4 && bobData.messages.size() == bobMsgSize + 4
+               && bob2Data.messages.size() == bob2MsgSize + 4;
+    }));
     auto msgId4 = aliceData.messages.rbegin()->id;
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId4, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId4, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId4, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bob2Data, msgId4, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
 
     // Second message is set to displayed by alice
     aliceAccount->setMessageDisplayed("swarm:" + aliceData.conversationId, msgId2, 3);
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED && getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
-                                                && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
+               && getMsgStatus(bob2Data, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
+               && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED
+               && getMsgStatus(bob2Data, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED;
+    }));
     // Other messages are still set to received
-    CPPUNIT_ASSERT(getMsgStatus(bobData, msgId3, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId3, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bobData, msgId4, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bob2Data, msgId4, aliceUri) == libjami::Account::MessageStates::SENT);
+    CPPUNIT_ASSERT(getMsgStatus(bobData, msgId3, aliceUri) == libjami::Account::MessageStates::SENT
+                   && getMsgStatus(bob2Data, msgId3, aliceUri) == libjami::Account::MessageStates::SENT
+                   && getMsgStatus(bobData, msgId4, aliceUri) == libjami::Account::MessageStates::SENT
+                   && getMsgStatus(bob2Data, msgId4, aliceUri) == libjami::Account::MessageStates::SENT);
 
     // Get conversation members should show the same information
     auto membersInfos = libjami::getConversationMembers(bobId, bobData.conversationId);
     CPPUNIT_ASSERT(std::find_if(membersInfos.begin(),
                                 membersInfos.end(),
-                                [&](auto infos) {
-                                    return infos["uri"] == aliceUri
-                                           && infos["lastDisplayed"] == msgId2;
-                                })
+                                [&](auto infos) { return infos["uri"] == aliceUri && infos["lastDisplayed"] == msgId2; })
                    != membersInfos.end());
 
     // Alice is disabled
@@ -471,9 +507,12 @@ ConversationFetchSentTest::testSyncFetch()
     libjami::sendMessage(bobId, bobData.conversationId, "6"s, "");
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return bob2Data.messages.size() == bob2MsgSize + 2; }));
     auto msgId5 = bobData.messages.rbegin()->id;
-    auto msgId6 = (bobData.messages.rbegin()+1)->id;
+    auto msgId6 = (bobData.messages.rbegin() + 1)->id;
     // No update
-    CPPUNIT_ASSERT(!cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId5, aliceUri) == libjami::Account::MessageStates::SENT && getMsgStatus(bobData, msgId6, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(!cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId5, aliceUri) == libjami::Account::MessageStates::SENT
+               && getMsgStatus(bobData, msgId6, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     // SwarmMessage will not get any status because nobody got the message
     CPPUNIT_ASSERT(getMsgStatus(bobData, msgId5, aliceUri) == libjami::Account::MessageStates::UNKNOWN);
     CPPUNIT_ASSERT(getMsgStatus(bobData, msgId6, aliceUri) == libjami::Account::MessageStates::UNKNOWN);
@@ -503,8 +542,8 @@ ConversationFetchSentTest::testDisplayedOnLoad()
     auto aliceMsgSize = aliceData.messages.size(), bobMsgSize = bobData.messages.size();
     libjami::sendMessage(bobId, bobData.conversationId, "1"s, "");
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
-        return aliceData.messages.size() == aliceMsgSize + 1
-                && bobData.messages.size() == bobMsgSize + 1; }));
+        return aliceData.messages.size() == aliceMsgSize + 1 && bobData.messages.size() == bobMsgSize + 1;
+    }));
     auto msgId1 = aliceData.messages.rbegin()->id;
     auto getMsgStatus = [&](const auto& data, const auto& id, const auto& peer) {
         for (const auto& msg : data.messages) {
@@ -514,16 +553,21 @@ ConversationFetchSentTest::testDisplayedOnLoad()
         }
         return libjami::Account::MessageStates::UNKNOWN;
     };
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::SENT; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::SENT;
+    }));
     libjami::sendMessage(bobId, bobData.conversationId, "2"s, "");
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceData.messages.size() == aliceMsgSize + 2
-                                                    && bobData.messages.size() == bobMsgSize + 2;}));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData.messages.size() == aliceMsgSize + 2 && bobData.messages.size() == bobMsgSize + 2;
+    }));
     auto msgId2 = aliceData.messages.rbegin()->id;
 
     // Second message is set to displayed by alice
     aliceAccount->setMessageDisplayed("swarm:" + aliceData.conversationId, msgId2, 3);
-    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
-                                                && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED; }));
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
+               && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED;
+    }));
 
     bobAccount->convModule()->loadConversations(); // Reset data
     bobData.messages.clear();
@@ -532,11 +576,10 @@ ConversationFetchSentTest::testDisplayedOnLoad()
     libjami::loadConversation(bobId, bobData.conversationId, "", 0);
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
         return getMsgStatus(bobData, msgId1, aliceUri) == libjami::Account::MessageStates::DISPLAYED
-                                                && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED; }));
-
+               && getMsgStatus(bobData, msgId2, aliceUri) == libjami::Account::MessageStates::DISPLAYED;
+    }));
 }
 
-
 } // namespace test
 } // namespace jami
 
