@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 #
-# Copyright (C) 2004-2025 Savoir-faire Linux Inc. Inc
+# Copyright (C) 2004-2026 Savoir-faire Linux Inc. Inc
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ class libjamiCtrl(Thread):
             proxy_confmgr.connect_to_signal('conversationReady', self.onConversationReady)
             proxy_confmgr.connect_to_signal('conversationRequestReceived', self.onConversationRequestReceived)
             proxy_confmgr.connect_to_signal('conversationPreferencesUpdated', self.onConversationPreferencesUpdated)
-            proxy_confmgr.connect_to_signal('messageReceived', self.onMessageReceived)
+            proxy_confmgr.connect_to_signal('swarmMessageReceived', self.onMessageReceived)
 
         except dbus.DBusException as e:
             raise libjamiCtrlDBusError("Unable to connect to jami DBus signals")
