@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -137,7 +137,7 @@ public:
     Q_INVOKABLE void joinCall(const QString& uri,
                               const QString& deviceId,
                               const QString& confId,
-                              bool isAudioOnly = false);
+                              bool videoMuted = true);
     Q_INVOKABLE void copyToDownloads(const QString& interactionId, const QString& displayName);
     Q_INVOKABLE void userIsComposing(bool isComposing);
     Q_INVOKABLE QVariantMap isLocalImage(const QString& mimeName);
@@ -191,4 +191,8 @@ private:
     static constexpr const int loadChunkSize_ {20};
     static constexpr const int timestampUpdateIntervalMs_ {1000};
     QLocale curLocale_;
+    QString dateFormatCurrentYear_;
+    QString dateFormatOtherYears_;
+
+    void updateDateFormats();
 };
