@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2017-2026 Savoir-faire Linux Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -202,14 +202,15 @@ public:
      * Call contacts linked to this conversation
      * @param uid of the conversation
      */
+    void startAudioOnlyCall(const QString& uid);
     void startCall(const QString& uid);
     /**
      * Perform an audio call with contacts linked to this conversation
      * @param uid of the conversation
      */
-    void startAudioOnlyCall(const QString& uid);
+    void placeAudioOnlyCall(const QString& uid);
     void joinCall(
-        const QString& uid, const QString& confId, const QString& uri, const QString& deviceId, bool isAudioOnly);
+        const QString& uid, const QString& confId, const QString& uri, const QString& deviceId, bool videoMuted);
     /**
      * Send a message to the conversation
      * @param uid of the conversation
